trait EntityEncoder[F[_], A] extends AnyRef
- Self Type
- EntityEncoder[F, A]
- Annotations
- @implicitNotFound()
- Source
- EntityEncoder.scala
- Alphabetic
- By Inheritance
- EntityEncoder
- AnyRef
- Any
- Hide All
- Show All
- Public
- Protected
Abstract Value Members
- abstract def headers: Headers
Headers that may be added to a Message
Headers that may be added to a Message
Examples of such headers would be Content-Type. NOTE: The Content-Length header will be generated from the resulting Entity and thus should not be added.
- abstract def toEntity(a: A): Entity[F]
Convert the type
Ato an Entity in the effect typeF
Concrete Value Members
- final def !=(arg0: Any): Boolean
- Definition Classes
- AnyRef → Any
- final def ##: Int
- Definition Classes
- AnyRef → Any
- final def ==(arg0: Any): Boolean
- Definition Classes
- AnyRef → Any
- final def asInstanceOf[T0]: T0
- Definition Classes
- Any
- def charset: Option[Charset]
Get the Charset of the body encoded by this EntityEncoder, if defined the headers
- def clone(): AnyRef
- Attributes
- protected[lang]
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.CloneNotSupportedException]) @native()
- def contentType: Option[Content-Type]
Get the org.http4s.headers.Content-Type of the body encoded by this EntityEncoder, if defined the headers
- def contramap[B](f: (B) => A): EntityEncoder[F, B]
Make a new EntityEncoder using this type as a foundation
- final def eq(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef
- def equals(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef → Any
- def finalize(): Unit
- Attributes
- protected[lang]
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.Throwable])
- final def getClass(): Class[_ <: AnyRef]
- Definition Classes
- AnyRef → Any
- Annotations
- @native()
- def hashCode(): Int
- Definition Classes
- AnyRef → Any
- Annotations
- @native()
- final def isInstanceOf[T0]: Boolean
- Definition Classes
- Any
- final def ne(arg0: AnyRef): Boolean
- Definition Classes
- AnyRef
- final def notify(): Unit
- Definition Classes
- AnyRef
- Annotations
- @native()
- final def notifyAll(): Unit
- Definition Classes
- AnyRef
- Annotations
- @native()
- final def synchronized[T0](arg0: => T0): T0
- Definition Classes
- AnyRef
- def toString(): String
- Definition Classes
- AnyRef → Any
- final def wait(): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException])
- final def wait(arg0: Long, arg1: Int): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException])
- final def wait(arg0: Long): Unit
- Definition Classes
- AnyRef
- Annotations
- @throws(classOf[java.lang.InterruptedException]) @native()
- def withContentType(tpe: Content-Type): EntityEncoder[F, A]
Generate a new EntityEncoder that will contain the
Content-Typeheader